% Postprocessing steady state plots for given solution vector
% and computed flux

function postprocessor

include_gblrefs;  

% Create figure for main field plots and get handle to it
fig_field = figure;

% Locate main field figure at left side of screen
screen_sizes = get(0,'ScreenSize');
fig_field_pos = get( fig_field, 'Position' );
fig_field_pos(1) = 0;
set( fig_field, 'Position', fig_field_pos );

% Plot main field response
plot(x,u,'Color','r');

% Setup labels
xlabel('x');
ylabel('u');
title('Trab3: steady-state field response');
hold on

% Dimension flux response arrays
x_flux = zeros(nel*2,1);
v_flux = zeros(nel*2,1);

% Compute flux response from given solution vector and plot it
for e=1:nel
 ni  = LM(1,e);                 % initial node of element
 nj  = LM(2,e);                 % final node of element
 le  = x(nj)-x(ni);             % compute element length
 ui  = u(ni);                   % initial element node field value
 uj  = u(nj);                   % final element node field value
 K   = Permeability(e);         % get element permeability coefficient

 x_flux(2*e-1) = x(ni);         % first flux point in element is located
                                %  at first element node
 x_flux(2*e)   = x(nj);         % second flux point in element is located
                                %  at last element node
 v_flux(2*e-1) = -K * (uj-ui)/le;
 v_flux(2*e)   = -K * (uj-ui)/le;
end

% Create figure for flux response plots and get handle to it
fig_flux = figure;

% Locate flux results figure at right side of screen
screen_sizes = get(0,'ScreenSize');
fig_flux_pos = get( fig_flux, 'Position' );
fig_flux_pos(1) = screen_sizes(3) - fig_flux_pos(3);
set( fig_flux, 'Position', fig_flux_pos );

% Plot given solution vector
plot(x_flux,v_flux,'Color','r');

% Setup labels
xlabel('x');
ylabel('q');
title('Trab3: steady-state flux response');
hold on

% Plot analytical solutions (if available)
if( nasp )
 figure( fig_field );
 plot(x_as,u_as,'Color','k');
 figure( fig_flux );
 plot(x_as,q_as,'Color','k');
end

