% Preprocessor:
% input data for 1D example of Trab2 with linear elements

function preprocessor

include_gblrefs;

% 1D domain parameters
L     = 80.0;            % length [m]
A     = 5.0;             % cross-section area [m2]
K     = 8.0e-6;          % permeability coefficient [m/s]
q     = 1.0e-6;          % distributed external source load [m/s]
H1    = 40.0;            % essencial B.C. at beginning (x = 0) [m]
H2    = 5.0;             % essencial B.C. at end (x = L) [m]

% Discretization parameters
nnp  =  6;               % number of nodal points
nel  =  5;               % number of elements

% Global equations coefficient matrices, RHS vector, and solution vector
Kg  = zeros(nnp,nnp);    % initialize global permeability matrix
F   = zeros(nnp,1);      % initialize global system forcing vector
u   = zeros(nnp,1);      % initialize global system solution vector

% Element properties vectors
CArea         = A*ones(nel,1);  % cross-section area
Permeability  = K*ones(nel,1);  % permeability coefficient

% B.C.'s
bc_init_flag = 1;
bc_end_flag  = 1;
bc_init_val  = H1;
bc_end_val   = H2;

% Element distributed source load vector
dist_load = ones(nel,1)*q;

% x coordinates array
x = zeros(nnp,1);
x = linspace(0.0,L,nnp);

% gather matrix = connectivity array
LM = zeros(2,nel);
LM(1,:) = (1:1:nnp-1);
LM(2,:) = (2:1:nnp);

% Steady-state analytical solution
nasp = 101;
x_as = zeros(nasp,1);
x_as = linspace(0.0,L,nasp);
for i=1:nasp
 u_as(i) = -0.0125*x_as(i)^2 + 0.5625*x_as(i) + 40.0;
 q_as(i) = -K * (-0.025*x_as(i) + 0.5625);
end

